/*
 * Copyright 2015, Yahoo Inc.
 * Copyrights licensed under the New BSD License.
 * See the accompanying LICENSE file for terms.
 */
export default function areIntlLocalesSupported(locales, constructorsToCheck) {
    if (typeof Intl === 'undefined') {
        return false;
    }
    if (!locales) {
        throw new Error('locales must be supplied.');
    }
    if (!Array.isArray(locales)) {
        locales = [locales];
    }
    // Per https://github.com/formatjs/formatjs/issues/151
    if (!constructorsToCheck) {
        constructorsToCheck = [
            Intl.DateTimeFormat,
            Intl.NumberFormat,
            Intl.PluralRules,
        ];
    }
    var intlConstructors = constructorsToCheck.filter(Boolean);
    if (intlConstructors.length === 0) {
        return false;
    }
    return intlConstructors.every(function (intlConstructor) {
        return intlConstructor.supportedLocalesOf(locales).length === locales.length;
    });
}
